Ocyan plugin opensourcepolicy
=============================

This plugin contains our opensource license policy.
The policy is defined in [policy.py](ocyan/plugin/opensourcepolicy/policy.py)

The plugin contains smoketests that run in every plugin/project and checks
for conformance to the policy of both python and javascript packages.

These tests are run every night and on every commit and will fail if a dependency
does not conform to our opensource policy.

Installation
-------------
Add `ocyan.plugin.opensourcepolicy` to your projects dependencies.

Describe how to install the plugin. 


About & Usage of opensourcepolicy
---------------------------------

Provides tools for enforcing our open source policy

It ships with a command that can be used to check you conformance to the policy:

```
manage.py check_opensource_policy
```
